@@ -27,6 +27,11 @@ class RelatedDrives(PluginTemplateExtension):
             virtual_machine=obj
         ).exclude(id__in=exclude_drive_id).order_by('identifier')
 
+        all_volumes = WindowsVolume.objects.all()
+        display_volume = []
+        for volume in all_volumes:
+            display_volume = volume.drives.all().intersection(drives)
+
         platform = obj.platform
         if platform is not None:
             if platform.name.lower().__contains__('windows'):
@@ -35,7 +40,8 @@ class RelatedDrives(PluginTemplateExtension):
                     extra_context={
                         "volumes": volumes,
                         "unmapped_drives": unmapped_drives,
-                        "type": type(obj.platform)
+                        "type": type(obj.platform),
+                        "display_volume": display_volume
                     },
                 )
             elif platform.name.lower().__contains__('linux'):
